from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class PressureChangeRateUnits(Enum):
        """
            PressureChangeRateUnits enumeration
        """
        
        PascalPerSecond = 'PascalPerSecond'
        """
            
        """
        
        PascalPerMinute = 'PascalPerMinute'
        """
            
        """
        
        MillimeterOfMercuryPerSecond = 'MillimeterOfMercuryPerSecond'
        """
            
        """
        
        AtmospherePerSecond = 'AtmospherePerSecond'
        """
            
        """
        
        PoundForcePerSquareInchPerSecond = 'PoundForcePerSquareInchPerSecond'
        """
            
        """
        
        PoundForcePerSquareInchPerMinute = 'PoundForcePerSquareInchPerMinute'
        """
            
        """
        
        BarPerSecond = 'BarPerSecond'
        """
            
        """
        
        BarPerMinute = 'BarPerMinute'
        """
            
        """
        
        KilopascalPerSecond = 'KilopascalPerSecond'
        """
            
        """
        
        MegapascalPerSecond = 'MegapascalPerSecond'
        """
            
        """
        
        KilopascalPerMinute = 'KilopascalPerMinute'
        """
            
        """
        
        MegapascalPerMinute = 'MegapascalPerMinute'
        """
            
        """
        
        KilopoundForcePerSquareInchPerSecond = 'KilopoundForcePerSquareInchPerSecond'
        """
            
        """
        
        MegapoundForcePerSquareInchPerSecond = 'MegapoundForcePerSquareInchPerSecond'
        """
            
        """
        
        KilopoundForcePerSquareInchPerMinute = 'KilopoundForcePerSquareInchPerMinute'
        """
            
        """
        
        MegapoundForcePerSquareInchPerMinute = 'MegapoundForcePerSquareInchPerMinute'
        """
            
        """
        
        MillibarPerSecond = 'MillibarPerSecond'
        """
            
        """
        
        MillibarPerMinute = 'MillibarPerMinute'
        """
            
        """
        

class PressureChangeRateDto:
    """
    A DTO representation of a PressureChangeRate

    Attributes:
        value (float): The value of the PressureChangeRate.
        unit (PressureChangeRateUnits): The specific unit that the PressureChangeRate value is representing.
    """

    def __init__(self, value: float, unit: PressureChangeRateUnits):
        """
        Create a new DTO representation of a PressureChangeRate

        Parameters:
            value (float): The value of the PressureChangeRate.
            unit (PressureChangeRateUnits): The specific unit that the PressureChangeRate value is representing.
        """
        self.value: float = value
        """
        The value of the PressureChangeRate
        """
        self.unit: PressureChangeRateUnits = unit
        """
        The specific unit that the PressureChangeRate value is representing
        """

    def to_json(self):
        """
        Get a PressureChangeRate DTO JSON object representing the current unit.

        :return: JSON object represents PressureChangeRate DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "PascalPerSecond"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of PressureChangeRate DTO from a json representation.

        :param data: The PressureChangeRate DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "PascalPerSecond"}
        :return: A new instance of PressureChangeRateDto.
        :rtype: PressureChangeRateDto
        """
        return PressureChangeRateDto(value=data["value"], unit=PressureChangeRateUnits(data["unit"]))


class PressureChangeRate(AbstractMeasure):
    """
    Pressure change rate is the ratio of the pressure change to the time during which the change occurred (value of pressure changes per unit time).

    Args:
        value (float): The value.
        from_unit (PressureChangeRateUnits): The PressureChangeRate unit to create from, The default unit is PascalPerSecond
    """
    def __init__(self, value: float, from_unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__pascals_per_second = None
        
        self.__pascals_per_minute = None
        
        self.__millimeters_of_mercury_per_second = None
        
        self.__atmospheres_per_second = None
        
        self.__pounds_force_per_square_inch_per_second = None
        
        self.__pounds_force_per_square_inch_per_minute = None
        
        self.__bars_per_second = None
        
        self.__bars_per_minute = None
        
        self.__kilopascals_per_second = None
        
        self.__megapascals_per_second = None
        
        self.__kilopascals_per_minute = None
        
        self.__megapascals_per_minute = None
        
        self.__kilopounds_force_per_square_inch_per_second = None
        
        self.__megapounds_force_per_square_inch_per_second = None
        
        self.__kilopounds_force_per_square_inch_per_minute = None
        
        self.__megapounds_force_per_square_inch_per_minute = None
        
        self.__millibars_per_second = None
        
        self.__millibars_per_minute = None
        

    def convert(self, unit: PressureChangeRateUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> PressureChangeRateDto:
        """
        Get a new instance of PressureChangeRate DTO representing the current unit.

        :param hold_in_unit: The specific PressureChangeRate unit to store the PressureChangeRate value in the DTO representation.
        :type hold_in_unit: PressureChangeRateUnits
        :return: A new instance of PressureChangeRateDto.
        :rtype: PressureChangeRateDto
        """
        return PressureChangeRateDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond):
        """
        Get a PressureChangeRate DTO JSON object representing the current unit.

        :param hold_in_unit: The specific PressureChangeRate unit to store the PressureChangeRate value in the DTO representation.
        :type hold_in_unit: PressureChangeRateUnits
        :return: JSON object represents PressureChangeRate DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "PascalPerSecond"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(pressure_change_rate_dto: PressureChangeRateDto):
        """
        Obtain a new instance of PressureChangeRate from a DTO unit object.

        :param pressure_change_rate_dto: The PressureChangeRate DTO representation.
        :type pressure_change_rate_dto: PressureChangeRateDto
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pressure_change_rate_dto.value, pressure_change_rate_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of PressureChangeRate from a DTO unit json representation.

        :param data: The PressureChangeRate DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "PascalPerSecond"}
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate.from_dto(PressureChangeRateDto.from_json(data))

    def __convert_from_base(self, from_unit: PressureChangeRateUnits) -> float:
        value = self._value
        
        if from_unit == PressureChangeRateUnits.PascalPerSecond:
            return (value)
        
        if from_unit == PressureChangeRateUnits.PascalPerMinute:
            return (value * 60)
        
        if from_unit == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return (value / 133.322)
        
        if from_unit == PressureChangeRateUnits.AtmospherePerSecond:
            return (value / (1.01325 * 1e5))
        
        if from_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return (value / 6.894757293168361e3)
        
        if from_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return (value / 6.894757293168361e3 * 60)
        
        if from_unit == PressureChangeRateUnits.BarPerSecond:
            return (value / 1e5)
        
        if from_unit == PressureChangeRateUnits.BarPerMinute:
            return (value / 1e5 * 60)
        
        if from_unit == PressureChangeRateUnits.KilopascalPerSecond:
            return ((value) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapascalPerSecond:
            return ((value) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.KilopascalPerMinute:
            return ((value * 60) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapascalPerMinute:
            return ((value * 60) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return ((value / 6.894757293168361e3) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return ((value / 6.894757293168361e3) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return ((value / 6.894757293168361e3 * 60) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return ((value / 6.894757293168361e3 * 60) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.MillibarPerSecond:
            return ((value / 1e5) / 0.001)
        
        if from_unit == PressureChangeRateUnits.MillibarPerMinute:
            return ((value / 1e5 * 60) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: PressureChangeRateUnits) -> float:
        
        if to_unit == PressureChangeRateUnits.PascalPerSecond:
            return (value)
        
        if to_unit == PressureChangeRateUnits.PascalPerMinute:
            return (value / 60)
        
        if to_unit == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return (value * 133.322)
        
        if to_unit == PressureChangeRateUnits.AtmospherePerSecond:
            return (value * 1.01325 * 1e5)
        
        if to_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return (value * 6.894757293168361e3)
        
        if to_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return (value * 6.894757293168361e3 / 60)
        
        if to_unit == PressureChangeRateUnits.BarPerSecond:
            return (value * 1e5)
        
        if to_unit == PressureChangeRateUnits.BarPerMinute:
            return (value * 1e5 / 60)
        
        if to_unit == PressureChangeRateUnits.KilopascalPerSecond:
            return ((value) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapascalPerSecond:
            return ((value) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.KilopascalPerMinute:
            return ((value / 60) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapascalPerMinute:
            return ((value / 60) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return ((value * 6.894757293168361e3) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return ((value * 6.894757293168361e3) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return ((value * 6.894757293168361e3 / 60) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return ((value * 6.894757293168361e3 / 60) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.MillibarPerSecond:
            return ((value * 1e5) * 0.001)
        
        if to_unit == PressureChangeRateUnits.MillibarPerMinute:
            return ((value * 1e5 / 60) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_pascals_per_second(pascals_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in pascals_per_second.

        

        :param meters: The PressureChangeRate value in pascals_per_second.
        :type pascals_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pascals_per_second, PressureChangeRateUnits.PascalPerSecond)

    
    @staticmethod
    def from_pascals_per_minute(pascals_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in pascals_per_minute.

        

        :param meters: The PressureChangeRate value in pascals_per_minute.
        :type pascals_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pascals_per_minute, PressureChangeRateUnits.PascalPerMinute)

    
    @staticmethod
    def from_millimeters_of_mercury_per_second(millimeters_of_mercury_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in millimeters_of_mercury_per_second.

        

        :param meters: The PressureChangeRate value in millimeters_of_mercury_per_second.
        :type millimeters_of_mercury_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(millimeters_of_mercury_per_second, PressureChangeRateUnits.MillimeterOfMercuryPerSecond)

    
    @staticmethod
    def from_atmospheres_per_second(atmospheres_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in atmospheres_per_second.

        

        :param meters: The PressureChangeRate value in atmospheres_per_second.
        :type atmospheres_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(atmospheres_per_second, PressureChangeRateUnits.AtmospherePerSecond)

    
    @staticmethod
    def from_pounds_force_per_square_inch_per_second(pounds_force_per_square_inch_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in pounds_force_per_square_inch_per_second.

        

        :param meters: The PressureChangeRate value in pounds_force_per_square_inch_per_second.
        :type pounds_force_per_square_inch_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pounds_force_per_square_inch_per_second, PressureChangeRateUnits.PoundForcePerSquareInchPerSecond)

    
    @staticmethod
    def from_pounds_force_per_square_inch_per_minute(pounds_force_per_square_inch_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in pounds_force_per_square_inch_per_minute.

        

        :param meters: The PressureChangeRate value in pounds_force_per_square_inch_per_minute.
        :type pounds_force_per_square_inch_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pounds_force_per_square_inch_per_minute, PressureChangeRateUnits.PoundForcePerSquareInchPerMinute)

    
    @staticmethod
    def from_bars_per_second(bars_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in bars_per_second.

        

        :param meters: The PressureChangeRate value in bars_per_second.
        :type bars_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(bars_per_second, PressureChangeRateUnits.BarPerSecond)

    
    @staticmethod
    def from_bars_per_minute(bars_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in bars_per_minute.

        

        :param meters: The PressureChangeRate value in bars_per_minute.
        :type bars_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(bars_per_minute, PressureChangeRateUnits.BarPerMinute)

    
    @staticmethod
    def from_kilopascals_per_second(kilopascals_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopascals_per_second.

        

        :param meters: The PressureChangeRate value in kilopascals_per_second.
        :type kilopascals_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopascals_per_second, PressureChangeRateUnits.KilopascalPerSecond)

    
    @staticmethod
    def from_megapascals_per_second(megapascals_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in megapascals_per_second.

        

        :param meters: The PressureChangeRate value in megapascals_per_second.
        :type megapascals_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapascals_per_second, PressureChangeRateUnits.MegapascalPerSecond)

    
    @staticmethod
    def from_kilopascals_per_minute(kilopascals_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopascals_per_minute.

        

        :param meters: The PressureChangeRate value in kilopascals_per_minute.
        :type kilopascals_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopascals_per_minute, PressureChangeRateUnits.KilopascalPerMinute)

    
    @staticmethod
    def from_megapascals_per_minute(megapascals_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in megapascals_per_minute.

        

        :param meters: The PressureChangeRate value in megapascals_per_minute.
        :type megapascals_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapascals_per_minute, PressureChangeRateUnits.MegapascalPerMinute)

    
    @staticmethod
    def from_kilopounds_force_per_square_inch_per_second(kilopounds_force_per_square_inch_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopounds_force_per_square_inch_per_second.

        

        :param meters: The PressureChangeRate value in kilopounds_force_per_square_inch_per_second.
        :type kilopounds_force_per_square_inch_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopounds_force_per_square_inch_per_second, PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond)

    
    @staticmethod
    def from_megapounds_force_per_square_inch_per_second(megapounds_force_per_square_inch_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in megapounds_force_per_square_inch_per_second.

        

        :param meters: The PressureChangeRate value in megapounds_force_per_square_inch_per_second.
        :type megapounds_force_per_square_inch_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapounds_force_per_square_inch_per_second, PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond)

    
    @staticmethod
    def from_kilopounds_force_per_square_inch_per_minute(kilopounds_force_per_square_inch_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopounds_force_per_square_inch_per_minute.

        

        :param meters: The PressureChangeRate value in kilopounds_force_per_square_inch_per_minute.
        :type kilopounds_force_per_square_inch_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopounds_force_per_square_inch_per_minute, PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute)

    
    @staticmethod
    def from_megapounds_force_per_square_inch_per_minute(megapounds_force_per_square_inch_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in megapounds_force_per_square_inch_per_minute.

        

        :param meters: The PressureChangeRate value in megapounds_force_per_square_inch_per_minute.
        :type megapounds_force_per_square_inch_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapounds_force_per_square_inch_per_minute, PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute)

    
    @staticmethod
    def from_millibars_per_second(millibars_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in millibars_per_second.

        

        :param meters: The PressureChangeRate value in millibars_per_second.
        :type millibars_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(millibars_per_second, PressureChangeRateUnits.MillibarPerSecond)

    
    @staticmethod
    def from_millibars_per_minute(millibars_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in millibars_per_minute.

        

        :param meters: The PressureChangeRate value in millibars_per_minute.
        :type millibars_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(millibars_per_minute, PressureChangeRateUnits.MillibarPerMinute)

    
    @property
    def pascals_per_second(self) -> float:
        """
        
        """
        if self.__pascals_per_second != None:
            return self.__pascals_per_second
        self.__pascals_per_second = self.__convert_from_base(PressureChangeRateUnits.PascalPerSecond)
        return self.__pascals_per_second

    
    @property
    def pascals_per_minute(self) -> float:
        """
        
        """
        if self.__pascals_per_minute != None:
            return self.__pascals_per_minute
        self.__pascals_per_minute = self.__convert_from_base(PressureChangeRateUnits.PascalPerMinute)
        return self.__pascals_per_minute

    
    @property
    def millimeters_of_mercury_per_second(self) -> float:
        """
        
        """
        if self.__millimeters_of_mercury_per_second != None:
            return self.__millimeters_of_mercury_per_second
        self.__millimeters_of_mercury_per_second = self.__convert_from_base(PressureChangeRateUnits.MillimeterOfMercuryPerSecond)
        return self.__millimeters_of_mercury_per_second

    
    @property
    def atmospheres_per_second(self) -> float:
        """
        
        """
        if self.__atmospheres_per_second != None:
            return self.__atmospheres_per_second
        self.__atmospheres_per_second = self.__convert_from_base(PressureChangeRateUnits.AtmospherePerSecond)
        return self.__atmospheres_per_second

    
    @property
    def pounds_force_per_square_inch_per_second(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_inch_per_second != None:
            return self.__pounds_force_per_square_inch_per_second
        self.__pounds_force_per_square_inch_per_second = self.__convert_from_base(PressureChangeRateUnits.PoundForcePerSquareInchPerSecond)
        return self.__pounds_force_per_square_inch_per_second

    
    @property
    def pounds_force_per_square_inch_per_minute(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_inch_per_minute != None:
            return self.__pounds_force_per_square_inch_per_minute
        self.__pounds_force_per_square_inch_per_minute = self.__convert_from_base(PressureChangeRateUnits.PoundForcePerSquareInchPerMinute)
        return self.__pounds_force_per_square_inch_per_minute

    
    @property
    def bars_per_second(self) -> float:
        """
        
        """
        if self.__bars_per_second != None:
            return self.__bars_per_second
        self.__bars_per_second = self.__convert_from_base(PressureChangeRateUnits.BarPerSecond)
        return self.__bars_per_second

    
    @property
    def bars_per_minute(self) -> float:
        """
        
        """
        if self.__bars_per_minute != None:
            return self.__bars_per_minute
        self.__bars_per_minute = self.__convert_from_base(PressureChangeRateUnits.BarPerMinute)
        return self.__bars_per_minute

    
    @property
    def kilopascals_per_second(self) -> float:
        """
        
        """
        if self.__kilopascals_per_second != None:
            return self.__kilopascals_per_second
        self.__kilopascals_per_second = self.__convert_from_base(PressureChangeRateUnits.KilopascalPerSecond)
        return self.__kilopascals_per_second

    
    @property
    def megapascals_per_second(self) -> float:
        """
        
        """
        if self.__megapascals_per_second != None:
            return self.__megapascals_per_second
        self.__megapascals_per_second = self.__convert_from_base(PressureChangeRateUnits.MegapascalPerSecond)
        return self.__megapascals_per_second

    
    @property
    def kilopascals_per_minute(self) -> float:
        """
        
        """
        if self.__kilopascals_per_minute != None:
            return self.__kilopascals_per_minute
        self.__kilopascals_per_minute = self.__convert_from_base(PressureChangeRateUnits.KilopascalPerMinute)
        return self.__kilopascals_per_minute

    
    @property
    def megapascals_per_minute(self) -> float:
        """
        
        """
        if self.__megapascals_per_minute != None:
            return self.__megapascals_per_minute
        self.__megapascals_per_minute = self.__convert_from_base(PressureChangeRateUnits.MegapascalPerMinute)
        return self.__megapascals_per_minute

    
    @property
    def kilopounds_force_per_square_inch_per_second(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_inch_per_second != None:
            return self.__kilopounds_force_per_square_inch_per_second
        self.__kilopounds_force_per_square_inch_per_second = self.__convert_from_base(PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond)
        return self.__kilopounds_force_per_square_inch_per_second

    
    @property
    def megapounds_force_per_square_inch_per_second(self) -> float:
        """
        
        """
        if self.__megapounds_force_per_square_inch_per_second != None:
            return self.__megapounds_force_per_square_inch_per_second
        self.__megapounds_force_per_square_inch_per_second = self.__convert_from_base(PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond)
        return self.__megapounds_force_per_square_inch_per_second

    
    @property
    def kilopounds_force_per_square_inch_per_minute(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_inch_per_minute != None:
            return self.__kilopounds_force_per_square_inch_per_minute
        self.__kilopounds_force_per_square_inch_per_minute = self.__convert_from_base(PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute)
        return self.__kilopounds_force_per_square_inch_per_minute

    
    @property
    def megapounds_force_per_square_inch_per_minute(self) -> float:
        """
        
        """
        if self.__megapounds_force_per_square_inch_per_minute != None:
            return self.__megapounds_force_per_square_inch_per_minute
        self.__megapounds_force_per_square_inch_per_minute = self.__convert_from_base(PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute)
        return self.__megapounds_force_per_square_inch_per_minute

    
    @property
    def millibars_per_second(self) -> float:
        """
        
        """
        if self.__millibars_per_second != None:
            return self.__millibars_per_second
        self.__millibars_per_second = self.__convert_from_base(PressureChangeRateUnits.MillibarPerSecond)
        return self.__millibars_per_second

    
    @property
    def millibars_per_minute(self) -> float:
        """
        
        """
        if self.__millibars_per_minute != None:
            return self.__millibars_per_minute
        self.__millibars_per_minute = self.__convert_from_base(PressureChangeRateUnits.MillibarPerMinute)
        return self.__millibars_per_minute

    
    def to_string(self, unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond, fractional_digits: int = None) -> str:
        """
        Format the PressureChangeRate to a string.
        
        Note: the default format for PressureChangeRate is PascalPerSecond.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the PressureChangeRate. Default is 'PascalPerSecond'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == PressureChangeRateUnits.PascalPerSecond:
            return f"""{super()._truncate_fraction_digits(self.pascals_per_second, fractional_digits)} Pa/s"""
        
        if unit == PressureChangeRateUnits.PascalPerMinute:
            return f"""{super()._truncate_fraction_digits(self.pascals_per_minute, fractional_digits)} Pa/min"""
        
        if unit == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return f"""{super()._truncate_fraction_digits(self.millimeters_of_mercury_per_second, fractional_digits)} mmHg/s"""
        
        if unit == PressureChangeRateUnits.AtmospherePerSecond:
            return f"""{super()._truncate_fraction_digits(self.atmospheres_per_second, fractional_digits)} atm/s"""
        
        if unit == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return f"""{super()._truncate_fraction_digits(self.pounds_force_per_square_inch_per_second, fractional_digits)} psi/s"""
        
        if unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return f"""{super()._truncate_fraction_digits(self.pounds_force_per_square_inch_per_minute, fractional_digits)} psi/min"""
        
        if unit == PressureChangeRateUnits.BarPerSecond:
            return f"""{super()._truncate_fraction_digits(self.bars_per_second, fractional_digits)} bar/s"""
        
        if unit == PressureChangeRateUnits.BarPerMinute:
            return f"""{super()._truncate_fraction_digits(self.bars_per_minute, fractional_digits)} bar/min"""
        
        if unit == PressureChangeRateUnits.KilopascalPerSecond:
            return f"""{super()._truncate_fraction_digits(self.kilopascals_per_second, fractional_digits)} kPa/s"""
        
        if unit == PressureChangeRateUnits.MegapascalPerSecond:
            return f"""{super()._truncate_fraction_digits(self.megapascals_per_second, fractional_digits)} MPa/s"""
        
        if unit == PressureChangeRateUnits.KilopascalPerMinute:
            return f"""{super()._truncate_fraction_digits(self.kilopascals_per_minute, fractional_digits)} kPa/min"""
        
        if unit == PressureChangeRateUnits.MegapascalPerMinute:
            return f"""{super()._truncate_fraction_digits(self.megapascals_per_minute, fractional_digits)} MPa/min"""
        
        if unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return f"""{super()._truncate_fraction_digits(self.kilopounds_force_per_square_inch_per_second, fractional_digits)} kpsi/s"""
        
        if unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return f"""{super()._truncate_fraction_digits(self.megapounds_force_per_square_inch_per_second, fractional_digits)} Mpsi/s"""
        
        if unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return f"""{super()._truncate_fraction_digits(self.kilopounds_force_per_square_inch_per_minute, fractional_digits)} kpsi/min"""
        
        if unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return f"""{super()._truncate_fraction_digits(self.megapounds_force_per_square_inch_per_minute, fractional_digits)} Mpsi/min"""
        
        if unit == PressureChangeRateUnits.MillibarPerSecond:
            return f"""{super()._truncate_fraction_digits(self.millibars_per_second, fractional_digits)} mbar/s"""
        
        if unit == PressureChangeRateUnits.MillibarPerMinute:
            return f"""{super()._truncate_fraction_digits(self.millibars_per_minute, fractional_digits)} mbar/min"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> str:
        """
        Get PressureChangeRate unit abbreviation.
        Note! the default abbreviation for PressureChangeRate is PascalPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == PressureChangeRateUnits.PascalPerSecond:
            return """Pa/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.PascalPerMinute:
            return """Pa/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return """mmHg/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.AtmospherePerSecond:
            return """atm/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return """psi/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return """psi/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.BarPerSecond:
            return """bar/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.BarPerMinute:
            return """bar/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopascalPerSecond:
            return """kPa/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapascalPerSecond:
            return """MPa/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopascalPerMinute:
            return """kPa/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapascalPerMinute:
            return """MPa/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return """kpsi/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return """Mpsi/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return """kpsi/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return """Mpsi/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.MillibarPerSecond:
            return """mbar/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.MillibarPerMinute:
            return """mbar/min"""
        


from .units.absorbed_dose_of_ionizing_radiation import AbsorbedDoseOfIonizingRadiation, AbsorbedDoseOfIonizingRadiationUnits, AbsorbedDoseOfIonizingRadiationDto
from .units.acceleration import Acceleration, AccelerationUnits, AccelerationDto
from .units.amount_of_substance import AmountOfSubstance, AmountOfSubstanceUnits, AmountOfSubstanceDto
from .units.amplitude_ratio import AmplitudeRatio, AmplitudeRatioUnits, AmplitudeRatioDto
from .units.angle import Angle, AngleUnits, AngleDto
from .units.apparent_energy import ApparentEnergy, ApparentEnergyUnits, ApparentEnergyDto
from .units.apparent_power import ApparentPower, ApparentPowerUnits, ApparentPowerDto
from .units.area import Area, AreaUnits, AreaDto
from .units.area_density import AreaDensity, AreaDensityUnits, AreaDensityDto
from .units.area_moment_of_inertia import AreaMomentOfInertia, AreaMomentOfInertiaUnits, AreaMomentOfInertiaDto
from .units.bit_rate import BitRate, BitRateUnits, BitRateDto
from .units.brake_specific_fuel_consumption import BrakeSpecificFuelConsumption, BrakeSpecificFuelConsumptionUnits, BrakeSpecificFuelConsumptionDto
from .units.capacitance import Capacitance, CapacitanceUnits, CapacitanceDto
from .units.coefficient_of_thermal_expansion import CoefficientOfThermalExpansion, CoefficientOfThermalExpansionUnits, CoefficientOfThermalExpansionDto
from .units.compressibility import Compressibility, CompressibilityUnits, CompressibilityDto
from .units.density import Density, DensityUnits, DensityDto
from .units.duration import Duration, DurationUnits, DurationDto
from .units.dynamic_viscosity import DynamicViscosity, DynamicViscosityUnits, DynamicViscosityDto
from .units.electric_admittance import ElectricAdmittance, ElectricAdmittanceUnits, ElectricAdmittanceDto
from .units.electric_charge import ElectricCharge, ElectricChargeUnits, ElectricChargeDto
from .units.electric_charge_density import ElectricChargeDensity, ElectricChargeDensityUnits, ElectricChargeDensityDto
from .units.electric_conductance import ElectricConductance, ElectricConductanceUnits, ElectricConductanceDto
from .units.electric_conductivity import ElectricConductivity, ElectricConductivityUnits, ElectricConductivityDto
from .units.electric_current import ElectricCurrent, ElectricCurrentUnits, ElectricCurrentDto
from .units.electric_current_density import ElectricCurrentDensity, ElectricCurrentDensityUnits, ElectricCurrentDensityDto
from .units.electric_current_gradient import ElectricCurrentGradient, ElectricCurrentGradientUnits, ElectricCurrentGradientDto
from .units.electric_field import ElectricField, ElectricFieldUnits, ElectricFieldDto
from .units.electric_inductance import ElectricInductance, ElectricInductanceUnits, ElectricInductanceDto
from .units.electric_potential import ElectricPotential, ElectricPotentialUnits, ElectricPotentialDto
from .units.electric_potential_ac import ElectricPotentialAc, ElectricPotentialAcUnits, ElectricPotentialAcDto
from .units.electric_potential_change_rate import ElectricPotentialChangeRate, ElectricPotentialChangeRateUnits, ElectricPotentialChangeRateDto
from .units.electric_potential_dc import ElectricPotentialDc, ElectricPotentialDcUnits, ElectricPotentialDcDto
from .units.electric_resistance import ElectricResistance, ElectricResistanceUnits, ElectricResistanceDto
from .units.electric_resistivity import ElectricResistivity, ElectricResistivityUnits, ElectricResistivityDto
from .units.electric_surface_charge_density import ElectricSurfaceChargeDensity, ElectricSurfaceChargeDensityUnits, ElectricSurfaceChargeDensityDto
from .units.energy import Energy, EnergyUnits, EnergyDto
from .units.energy_density import EnergyDensity, EnergyDensityUnits, EnergyDensityDto
from .units.entropy import Entropy, EntropyUnits, EntropyDto
from .units.force import Force, ForceUnits, ForceDto
from .units.force_change_rate import ForceChangeRate, ForceChangeRateUnits, ForceChangeRateDto
from .units.force_per_length import ForcePerLength, ForcePerLengthUnits, ForcePerLengthDto
from .units.frequency import Frequency, FrequencyUnits, FrequencyDto
from .units.fuel_efficiency import FuelEfficiency, FuelEfficiencyUnits, FuelEfficiencyDto
from .units.heat_flux import HeatFlux, HeatFluxUnits, HeatFluxDto
from .units.heat_transfer_coefficient import HeatTransferCoefficient, HeatTransferCoefficientUnits, HeatTransferCoefficientDto
from .units.illuminance import Illuminance, IlluminanceUnits, IlluminanceDto
from .units.impulse import Impulse, ImpulseUnits, ImpulseDto
from .units.information import Information, InformationUnits, InformationDto
from .units.irradiance import Irradiance, IrradianceUnits, IrradianceDto
from .units.irradiation import Irradiation, IrradiationUnits, IrradiationDto
from .units.jerk import Jerk, JerkUnits, JerkDto
from .units.kinematic_viscosity import KinematicViscosity, KinematicViscosityUnits, KinematicViscosityDto
from .units.leak_rate import LeakRate, LeakRateUnits, LeakRateDto
from .units.length import Length, LengthUnits, LengthDto
from .units.level import Level, LevelUnits, LevelDto
from .units.linear_density import LinearDensity, LinearDensityUnits, LinearDensityDto
from .units.linear_power_density import LinearPowerDensity, LinearPowerDensityUnits, LinearPowerDensityDto
from .units.luminance import Luminance, LuminanceUnits, LuminanceDto
from .units.luminosity import Luminosity, LuminosityUnits, LuminosityDto
from .units.luminous_flux import LuminousFlux, LuminousFluxUnits, LuminousFluxDto
from .units.luminous_intensity import LuminousIntensity, LuminousIntensityUnits, LuminousIntensityDto
from .units.magnetic_field import MagneticField, MagneticFieldUnits, MagneticFieldDto
from .units.magnetic_flux import MagneticFlux, MagneticFluxUnits, MagneticFluxDto
from .units.magnetization import Magnetization, MagnetizationUnits, MagnetizationDto
from .units.mass import Mass, MassUnits, MassDto
from .units.mass_concentration import MassConcentration, MassConcentrationUnits, MassConcentrationDto
from .units.mass_flow import MassFlow, MassFlowUnits, MassFlowDto
from .units.mass_flux import MassFlux, MassFluxUnits, MassFluxDto
from .units.mass_fraction import MassFraction, MassFractionUnits, MassFractionDto
from .units.mass_moment_of_inertia import MassMomentOfInertia, MassMomentOfInertiaUnits, MassMomentOfInertiaDto
from .units.molality import Molality, MolalityUnits, MolalityDto
from .units.molar_energy import MolarEnergy, MolarEnergyUnits, MolarEnergyDto
from .units.molar_entropy import MolarEntropy, MolarEntropyUnits, MolarEntropyDto
from .units.molar_flow import MolarFlow, MolarFlowUnits, MolarFlowDto
from .units.molar_mass import MolarMass, MolarMassUnits, MolarMassDto
from .units.molarity import Molarity, MolarityUnits, MolarityDto
from .units.permeability import Permeability, PermeabilityUnits, PermeabilityDto
from .units.permittivity import Permittivity, PermittivityUnits, PermittivityDto
from .units.porous_medium_permeability import PorousMediumPermeability, PorousMediumPermeabilityUnits, PorousMediumPermeabilityDto
from .units.power import Power, PowerUnits, PowerDto
from .units.power_density import PowerDensity, PowerDensityUnits, PowerDensityDto
from .units.power_ratio import PowerRatio, PowerRatioUnits, PowerRatioDto
from .units.pressure import Pressure, PressureUnits, PressureDto
from .units.pressure_change_rate import PressureChangeRate, PressureChangeRateUnits, PressureChangeRateDto
from .units.radiation_equivalent_dose import RadiationEquivalentDose, RadiationEquivalentDoseUnits, RadiationEquivalentDoseDto
from .units.radiation_exposure import RadiationExposure, RadiationExposureUnits, RadiationExposureDto
from .units.radioactivity import Radioactivity, RadioactivityUnits, RadioactivityDto
from .units.ratio import Ratio, RatioUnits, RatioDto
from .units.ratio_change_rate import RatioChangeRate, RatioChangeRateUnits, RatioChangeRateDto
from .units.reactive_energy import ReactiveEnergy, ReactiveEnergyUnits, ReactiveEnergyDto
from .units.reactive_power import ReactivePower, ReactivePowerUnits, ReactivePowerDto
from .units.reciprocal_area import ReciprocalArea, ReciprocalAreaUnits, ReciprocalAreaDto
from .units.reciprocal_length import ReciprocalLength, ReciprocalLengthUnits, ReciprocalLengthDto
from .units.relative_humidity import RelativeHumidity, RelativeHumidityUnits, RelativeHumidityDto
from .units.rotational_acceleration import RotationalAcceleration, RotationalAccelerationUnits, RotationalAccelerationDto
from .units.rotational_speed import RotationalSpeed, RotationalSpeedUnits, RotationalSpeedDto
from .units.rotational_stiffness import RotationalStiffness, RotationalStiffnessUnits, RotationalStiffnessDto
from .units.rotational_stiffness_per_length import RotationalStiffnessPerLength, RotationalStiffnessPerLengthUnits, RotationalStiffnessPerLengthDto
from .units.scalar import Scalar, ScalarUnits, ScalarDto
from .units.solid_angle import SolidAngle, SolidAngleUnits, SolidAngleDto
from .units.specific_energy import SpecificEnergy, SpecificEnergyUnits, SpecificEnergyDto
from .units.specific_entropy import SpecificEntropy, SpecificEntropyUnits, SpecificEntropyDto
from .units.specific_fuel_consumption import SpecificFuelConsumption, SpecificFuelConsumptionUnits, SpecificFuelConsumptionDto
from .units.specific_volume import SpecificVolume, SpecificVolumeUnits, SpecificVolumeDto
from .units.specific_weight import SpecificWeight, SpecificWeightUnits, SpecificWeightDto
from .units.speed import Speed, SpeedUnits, SpeedDto
from .units.standard_volume_flow import StandardVolumeFlow, StandardVolumeFlowUnits, StandardVolumeFlowDto
from .units.temperature import Temperature, TemperatureUnits, TemperatureDto
from .units.temperature_change_rate import TemperatureChangeRate, TemperatureChangeRateUnits, TemperatureChangeRateDto
from .units.temperature_delta import TemperatureDelta, TemperatureDeltaUnits, TemperatureDeltaDto
from .units.temperature_gradient import TemperatureGradient, TemperatureGradientUnits, TemperatureGradientDto
from .units.thermal_conductivity import ThermalConductivity, ThermalConductivityUnits, ThermalConductivityDto
from .units.thermal_resistance import ThermalResistance, ThermalResistanceUnits, ThermalResistanceDto
from .units.torque import Torque, TorqueUnits, TorqueDto
from .units.torque_per_length import TorquePerLength, TorquePerLengthUnits, TorquePerLengthDto
from .units.turbidity import Turbidity, TurbidityUnits, TurbidityDto
from .units.vitamin_a import VitaminA, VitaminAUnits, VitaminADto
from .units.volume import Volume, VolumeUnits, VolumeDto
from .units.volume_concentration import VolumeConcentration, VolumeConcentrationUnits, VolumeConcentrationDto
from .units.volume_flow import VolumeFlow, VolumeFlowUnits, VolumeFlowDto
from .units.volume_flow_per_area import VolumeFlowPerArea, VolumeFlowPerAreaUnits, VolumeFlowPerAreaDto
from .units.volume_per_length import VolumePerLength, VolumePerLengthUnits, VolumePerLengthDto
from .units.volumetric_heat_capacity import VolumetricHeatCapacity, VolumetricHeatCapacityUnits, VolumetricHeatCapacityDto
from .units.warping_moment_of_inertia import WarpingMomentOfInertia, WarpingMomentOfInertiaUnits, WarpingMomentOfInertiaDto


__all__ = [
 'AbsorbedDoseOfIonizingRadiation', 'AbsorbedDoseOfIonizingRadiationUnits', 'AbsorbedDoseOfIonizingRadiationDto',
 'Acceleration', 'AccelerationUnits', 'AccelerationDto',
 'AmountOfSubstance', 'AmountOfSubstanceUnits', 'AmountOfSubstanceDto',
 'AmplitudeRatio', 'AmplitudeRatioUnits', 'AmplitudeRatioDto',
 'Angle', 'AngleUnits', 'AngleDto',
 'ApparentEnergy', 'ApparentEnergyUnits', 'ApparentEnergyDto',
 'ApparentPower', 'ApparentPowerUnits', 'ApparentPowerDto',
 'Area', 'AreaUnits', 'AreaDto',
 'AreaDensity', 'AreaDensityUnits', 'AreaDensityDto',
 'AreaMomentOfInertia', 'AreaMomentOfInertiaUnits', 'AreaMomentOfInertiaDto',
 'BitRate', 'BitRateUnits', 'BitRateDto',
 'BrakeSpecificFuelConsumption', 'BrakeSpecificFuelConsumptionUnits', 'BrakeSpecificFuelConsumptionDto',
 'Capacitance', 'CapacitanceUnits', 'CapacitanceDto',
 'CoefficientOfThermalExpansion', 'CoefficientOfThermalExpansionUnits', 'CoefficientOfThermalExpansionDto',
 'Compressibility', 'CompressibilityUnits', 'CompressibilityDto',
 'Density', 'DensityUnits', 'DensityDto',
 'Duration', 'DurationUnits', 'DurationDto',
 'DynamicViscosity', 'DynamicViscosityUnits', 'DynamicViscosityDto',
 'ElectricAdmittance', 'ElectricAdmittanceUnits', 'ElectricAdmittanceDto',
 'ElectricCharge', 'ElectricChargeUnits', 'ElectricChargeDto',
 'ElectricChargeDensity', 'ElectricChargeDensityUnits', 'ElectricChargeDensityDto',
 'ElectricConductance', 'ElectricConductanceUnits', 'ElectricConductanceDto',
 'ElectricConductivity', 'ElectricConductivityUnits', 'ElectricConductivityDto',
 'ElectricCurrent', 'ElectricCurrentUnits', 'ElectricCurrentDto',
 'ElectricCurrentDensity', 'ElectricCurrentDensityUnits', 'ElectricCurrentDensityDto',
 'ElectricCurrentGradient', 'ElectricCurrentGradientUnits', 'ElectricCurrentGradientDto',
 'ElectricField', 'ElectricFieldUnits', 'ElectricFieldDto',
 'ElectricInductance', 'ElectricInductanceUnits', 'ElectricInductanceDto',
 'ElectricPotential', 'ElectricPotentialUnits', 'ElectricPotentialDto',
 'ElectricPotentialAc', 'ElectricPotentialAcUnits', 'ElectricPotentialAcDto',
 'ElectricPotentialChangeRate', 'ElectricPotentialChangeRateUnits', 'ElectricPotentialChangeRateDto',
 'ElectricPotentialDc', 'ElectricPotentialDcUnits', 'ElectricPotentialDcDto',
 'ElectricResistance', 'ElectricResistanceUnits', 'ElectricResistanceDto',
 'ElectricResistivity', 'ElectricResistivityUnits', 'ElectricResistivityDto',
 'ElectricSurfaceChargeDensity', 'ElectricSurfaceChargeDensityUnits', 'ElectricSurfaceChargeDensityDto',
 'Energy', 'EnergyUnits', 'EnergyDto',
 'EnergyDensity', 'EnergyDensityUnits', 'EnergyDensityDto',
 'Entropy', 'EntropyUnits', 'EntropyDto',
 'Force', 'ForceUnits', 'ForceDto',
 'ForceChangeRate', 'ForceChangeRateUnits', 'ForceChangeRateDto',
 'ForcePerLength', 'ForcePerLengthUnits', 'ForcePerLengthDto',
 'Frequency', 'FrequencyUnits', 'FrequencyDto',
 'FuelEfficiency', 'FuelEfficiencyUnits', 'FuelEfficiencyDto',
 'HeatFlux', 'HeatFluxUnits', 'HeatFluxDto',
 'HeatTransferCoefficient', 'HeatTransferCoefficientUnits', 'HeatTransferCoefficientDto',
 'Illuminance', 'IlluminanceUnits', 'IlluminanceDto',
 'Impulse', 'ImpulseUnits', 'ImpulseDto',
 'Information', 'InformationUnits', 'InformationDto',
 'Irradiance', 'IrradianceUnits', 'IrradianceDto',
 'Irradiation', 'IrradiationUnits', 'IrradiationDto',
 'Jerk', 'JerkUnits', 'JerkDto',
 'KinematicViscosity', 'KinematicViscosityUnits', 'KinematicViscosityDto',
 'LeakRate', 'LeakRateUnits', 'LeakRateDto',
 'Length', 'LengthUnits', 'LengthDto',
 'Level', 'LevelUnits', 'LevelDto',
 'LinearDensity', 'LinearDensityUnits', 'LinearDensityDto',
 'LinearPowerDensity', 'LinearPowerDensityUnits', 'LinearPowerDensityDto',
 'Luminance', 'LuminanceUnits', 'LuminanceDto',
 'Luminosity', 'LuminosityUnits', 'LuminosityDto',
 'LuminousFlux', 'LuminousFluxUnits', 'LuminousFluxDto',
 'LuminousIntensity', 'LuminousIntensityUnits', 'LuminousIntensityDto',
 'MagneticField', 'MagneticFieldUnits', 'MagneticFieldDto',
 'MagneticFlux', 'MagneticFluxUnits', 'MagneticFluxDto',
 'Magnetization', 'MagnetizationUnits', 'MagnetizationDto',
 'Mass', 'MassUnits', 'MassDto',
 'MassConcentration', 'MassConcentrationUnits', 'MassConcentrationDto',
 'MassFlow', 'MassFlowUnits', 'MassFlowDto',
 'MassFlux', 'MassFluxUnits', 'MassFluxDto',
 'MassFraction', 'MassFractionUnits', 'MassFractionDto',
 'MassMomentOfInertia', 'MassMomentOfInertiaUnits', 'MassMomentOfInertiaDto',
 'Molality', 'MolalityUnits', 'MolalityDto',
 'MolarEnergy', 'MolarEnergyUnits', 'MolarEnergyDto',
 'MolarEntropy', 'MolarEntropyUnits', 'MolarEntropyDto',
 'MolarFlow', 'MolarFlowUnits', 'MolarFlowDto',
 'MolarMass', 'MolarMassUnits', 'MolarMassDto',
 'Molarity', 'MolarityUnits', 'MolarityDto',
 'Permeability', 'PermeabilityUnits', 'PermeabilityDto',
 'Permittivity', 'PermittivityUnits', 'PermittivityDto',
 'PorousMediumPermeability', 'PorousMediumPermeabilityUnits', 'PorousMediumPermeabilityDto',
 'Power', 'PowerUnits', 'PowerDto',
 'PowerDensity', 'PowerDensityUnits', 'PowerDensityDto',
 'PowerRatio', 'PowerRatioUnits', 'PowerRatioDto',
 'Pressure', 'PressureUnits', 'PressureDto',
 'PressureChangeRate', 'PressureChangeRateUnits', 'PressureChangeRateDto',
 'RadiationEquivalentDose', 'RadiationEquivalentDoseUnits', 'RadiationEquivalentDoseDto',
 'RadiationExposure', 'RadiationExposureUnits', 'RadiationExposureDto',
 'Radioactivity', 'RadioactivityUnits', 'RadioactivityDto',
 'Ratio', 'RatioUnits', 'RatioDto',
 'RatioChangeRate', 'RatioChangeRateUnits', 'RatioChangeRateDto',
 'ReactiveEnergy', 'ReactiveEnergyUnits', 'ReactiveEnergyDto',
 'ReactivePower', 'ReactivePowerUnits', 'ReactivePowerDto',
 'ReciprocalArea', 'ReciprocalAreaUnits', 'ReciprocalAreaDto',
 'ReciprocalLength', 'ReciprocalLengthUnits', 'ReciprocalLengthDto',
 'RelativeHumidity', 'RelativeHumidityUnits', 'RelativeHumidityDto',
 'RotationalAcceleration', 'RotationalAccelerationUnits', 'RotationalAccelerationDto',
 'RotationalSpeed', 'RotationalSpeedUnits', 'RotationalSpeedDto',
 'RotationalStiffness', 'RotationalStiffnessUnits', 'RotationalStiffnessDto',
 'RotationalStiffnessPerLength', 'RotationalStiffnessPerLengthUnits', 'RotationalStiffnessPerLengthDto',
 'Scalar', 'ScalarUnits', 'ScalarDto',
 'SolidAngle', 'SolidAngleUnits', 'SolidAngleDto',
 'SpecificEnergy', 'SpecificEnergyUnits', 'SpecificEnergyDto',
 'SpecificEntropy', 'SpecificEntropyUnits', 'SpecificEntropyDto',
 'SpecificFuelConsumption', 'SpecificFuelConsumptionUnits', 'SpecificFuelConsumptionDto',
 'SpecificVolume', 'SpecificVolumeUnits', 'SpecificVolumeDto',
 'SpecificWeight', 'SpecificWeightUnits', 'SpecificWeightDto',
 'Speed', 'SpeedUnits', 'SpeedDto',
 'StandardVolumeFlow', 'StandardVolumeFlowUnits', 'StandardVolumeFlowDto',
 'Temperature', 'TemperatureUnits', 'TemperatureDto',
 'TemperatureChangeRate', 'TemperatureChangeRateUnits', 'TemperatureChangeRateDto',
 'TemperatureDelta', 'TemperatureDeltaUnits', 'TemperatureDeltaDto',
 'TemperatureGradient', 'TemperatureGradientUnits', 'TemperatureGradientDto',
 'ThermalConductivity', 'ThermalConductivityUnits', 'ThermalConductivityDto',
 'ThermalResistance', 'ThermalResistanceUnits', 'ThermalResistanceDto',
 'Torque', 'TorqueUnits', 'TorqueDto',
 'TorquePerLength', 'TorquePerLengthUnits', 'TorquePerLengthDto',
 'Turbidity', 'TurbidityUnits', 'TurbidityDto',
 'VitaminA', 'VitaminAUnits', 'VitaminADto',
 'Volume', 'VolumeUnits', 'VolumeDto',
 'VolumeConcentration', 'VolumeConcentrationUnits', 'VolumeConcentrationDto',
 'VolumeFlow', 'VolumeFlowUnits', 'VolumeFlowDto',
 'VolumeFlowPerArea', 'VolumeFlowPerAreaUnits', 'VolumeFlowPerAreaDto',
 'VolumePerLength', 'VolumePerLengthUnits', 'VolumePerLengthDto',
 'VolumetricHeatCapacity', 'VolumetricHeatCapacityUnits', 'VolumetricHeatCapacityDto',
 'WarpingMomentOfInertia', 'WarpingMomentOfInertiaUnits', 'WarpingMomentOfInertiaDto',
]


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class LinearDensityUnits(Enum):
        """
            LinearDensityUnits enumeration
        """
        
        GramPerMillimeter = 'GramPerMillimeter'
        """
            
        """
        
        GramPerCentimeter = 'GramPerCentimeter'
        """
            
        """
        
        GramPerMeter = 'GramPerMeter'
        """
            
        """
        
        PoundPerInch = 'PoundPerInch'
        """
            
        """
        
        PoundPerFoot = 'PoundPerFoot'
        """
            
        """
        
        GramPerFoot = 'GramPerFoot'
        """
            
        """
        
        MicrogramPerMillimeter = 'MicrogramPerMillimeter'
        """
            
        """
        
        MilligramPerMillimeter = 'MilligramPerMillimeter'
        """
            
        """
        
        KilogramPerMillimeter = 'KilogramPerMillimeter'
        """
            
        """
        
        MicrogramPerCentimeter = 'MicrogramPerCentimeter'
        """
            
        """
        
        MilligramPerCentimeter = 'MilligramPerCentimeter'
        """
            
        """
        
        KilogramPerCentimeter = 'KilogramPerCentimeter'
        """
            
        """
        
        MicrogramPerMeter = 'MicrogramPerMeter'
        """
            
        """
        
        MilligramPerMeter = 'MilligramPerMeter'
        """
            
        """
        
        KilogramPerMeter = 'KilogramPerMeter'
        """
            
        """
        
        MicrogramPerFoot = 'MicrogramPerFoot'
        """
            
        """
        
        MilligramPerFoot = 'MilligramPerFoot'
        """
            
        """
        
        KilogramPerFoot = 'KilogramPerFoot'
        """
            
        """
        

class LinearDensityDto:
    """
    A DTO representation of a LinearDensity

    Attributes:
        value (float): The value of the LinearDensity.
        unit (LinearDensityUnits): The specific unit that the LinearDensity value is representing.
    """

    def __init__(self, value: float, unit: LinearDensityUnits):
        """
        Create a new DTO representation of a LinearDensity

        Parameters:
            value (float): The value of the LinearDensity.
            unit (LinearDensityUnits): The specific unit that the LinearDensity value is representing.
        """
        self.value: float = value
        """
        The value of the LinearDensity
        """
        self.unit: LinearDensityUnits = unit
        """
        The specific unit that the LinearDensity value is representing
        """

    def to_json(self):
        """
        Get a LinearDensity DTO JSON object representing the current unit.

        :return: JSON object represents LinearDensity DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "KilogramPerMeter"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of LinearDensity DTO from a json representation.

        :param data: The LinearDensity DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "KilogramPerMeter"}
        :return: A new instance of LinearDensityDto.
        :rtype: LinearDensityDto
        """
        return LinearDensityDto(value=data["value"], unit=LinearDensityUnits(data["unit"]))


class LinearDensity(AbstractMeasure):
    """
    The Linear Density, or more precisely, the linear mass density, of a substance is its mass per unit length.  The term linear density is most often used when describing the characteristics of one-dimensional objects, although linear density can also be used to describe the density of a three-dimensional quantity along one particular dimension.

    Args:
        value (float): The value.
        from_unit (LinearDensityUnits): The LinearDensity unit to create from, The default unit is KilogramPerMeter
    """
    def __init__(self, value: float, from_unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__grams_per_millimeter = None
        
        self.__grams_per_centimeter = None
        
        self.__grams_per_meter = None
        
        self.__pounds_per_inch = None
        
        self.__pounds_per_foot = None
        
        self.__grams_per_foot = None
        
        self.__micrograms_per_millimeter = None
        
        self.__milligrams_per_millimeter = None
        
        self.__kilograms_per_millimeter = None
        
        self.__micrograms_per_centimeter = None
        
        self.__milligrams_per_centimeter = None
        
        self.__kilograms_per_centimeter = None
        
        self.__micrograms_per_meter = None
        
        self.__milligrams_per_meter = None
        
        self.__kilograms_per_meter = None
        
        self.__micrograms_per_foot = None
        
        self.__milligrams_per_foot = None
        
        self.__kilograms_per_foot = None
        

    def convert(self, unit: LinearDensityUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> LinearDensityDto:
        """
        Get a new instance of LinearDensity DTO representing the current unit.

        :param hold_in_unit: The specific LinearDensity unit to store the LinearDensity value in the DTO representation.
        :type hold_in_unit: LinearDensityUnits
        :return: A new instance of LinearDensityDto.
        :rtype: LinearDensityDto
        """
        return LinearDensityDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter):
        """
        Get a LinearDensity DTO JSON object representing the current unit.

        :param hold_in_unit: The specific LinearDensity unit to store the LinearDensity value in the DTO representation.
        :type hold_in_unit: LinearDensityUnits
        :return: JSON object represents LinearDensity DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "KilogramPerMeter"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(linear_density_dto: LinearDensityDto):
        """
        Obtain a new instance of LinearDensity from a DTO unit object.

        :param linear_density_dto: The LinearDensity DTO representation.
        :type linear_density_dto: LinearDensityDto
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(linear_density_dto.value, linear_density_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of LinearDensity from a DTO unit json representation.

        :param data: The LinearDensity DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "KilogramPerMeter"}
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity.from_dto(LinearDensityDto.from_json(data))

    def __convert_from_base(self, from_unit: LinearDensityUnits) -> float:
        value = self._value
        
        if from_unit == LinearDensityUnits.GramPerMillimeter:
            return (value)
        
        if from_unit == LinearDensityUnits.GramPerCentimeter:
            return (value / 1e-1)
        
        if from_unit == LinearDensityUnits.GramPerMeter:
            return (value / 1e-3)
        
        if from_unit == LinearDensityUnits.PoundPerInch:
            return (value * 5.5997415e-2)
        
        if from_unit == LinearDensityUnits.PoundPerFoot:
            return (value / 1.48816394)
        
        if from_unit == LinearDensityUnits.GramPerFoot:
            return (value / ( 1e-3 / 0.3048 ))
        
        if from_unit == LinearDensityUnits.MicrogramPerMillimeter:
            return ((value) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerMillimeter:
            return ((value) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerMillimeter:
            return ((value) / 1000.0)
        
        if from_unit == LinearDensityUnits.MicrogramPerCentimeter:
            return ((value / 1e-1) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerCentimeter:
            return ((value / 1e-1) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerCentimeter:
            return ((value / 1e-1) / 1000.0)
        
        if from_unit == LinearDensityUnits.MicrogramPerMeter:
            return ((value / 1e-3) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerMeter:
            return ((value / 1e-3) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerMeter:
            return ((value / 1e-3) / 1000.0)
        
        if from_unit == LinearDensityUnits.MicrogramPerFoot:
            return ((value / ( 1e-3 / 0.3048 )) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerFoot:
            return ((value / ( 1e-3 / 0.3048 )) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerFoot:
            return ((value / ( 1e-3 / 0.3048 )) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LinearDensityUnits) -> float:
        
        if to_unit == LinearDensityUnits.GramPerMillimeter:
            return (value)
        
        if to_unit == LinearDensityUnits.GramPerCentimeter:
            return (value * 1e-1)
        
        if to_unit == LinearDensityUnits.GramPerMeter:
            return (value * 1e-3)
        
        if to_unit == LinearDensityUnits.PoundPerInch:
            return (value / 5.5997415e-2)
        
        if to_unit == LinearDensityUnits.PoundPerFoot:
            return (value * 1.48816394)
        
        if to_unit == LinearDensityUnits.GramPerFoot:
            return (value * ( 1e-3 / 0.3048 ))
        
        if to_unit == LinearDensityUnits.MicrogramPerMillimeter:
            return ((value) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerMillimeter:
            return ((value) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerMillimeter:
            return ((value) * 1000.0)
        
        if to_unit == LinearDensityUnits.MicrogramPerCentimeter:
            return ((value * 1e-1) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerCentimeter:
            return ((value * 1e-1) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerCentimeter:
            return ((value * 1e-1) * 1000.0)
        
        if to_unit == LinearDensityUnits.MicrogramPerMeter:
            return ((value * 1e-3) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerMeter:
            return ((value * 1e-3) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerMeter:
            return ((value * 1e-3) * 1000.0)
        
        if to_unit == LinearDensityUnits.MicrogramPerFoot:
            return ((value * ( 1e-3 / 0.3048 )) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerFoot:
            return ((value * ( 1e-3 / 0.3048 )) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerFoot:
            return ((value * ( 1e-3 / 0.3048 )) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_grams_per_millimeter(grams_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_millimeter.

        

        :param meters: The LinearDensity value in grams_per_millimeter.
        :type grams_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_millimeter, LinearDensityUnits.GramPerMillimeter)

    
    @staticmethod
    def from_grams_per_centimeter(grams_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_centimeter.

        

        :param meters: The LinearDensity value in grams_per_centimeter.
        :type grams_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_centimeter, LinearDensityUnits.GramPerCentimeter)

    
    @staticmethod
    def from_grams_per_meter(grams_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_meter.

        

        :param meters: The LinearDensity value in grams_per_meter.
        :type grams_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_meter, LinearDensityUnits.GramPerMeter)

    
    @staticmethod
    def from_pounds_per_inch(pounds_per_inch: float):
        """
        Create a new instance of LinearDensity from a value in pounds_per_inch.

        

        :param meters: The LinearDensity value in pounds_per_inch.
        :type pounds_per_inch: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(pounds_per_inch, LinearDensityUnits.PoundPerInch)

    
    @staticmethod
    def from_pounds_per_foot(pounds_per_foot: float):
        """
        Create a new instance of LinearDensity from a value in pounds_per_foot.

        

        :param meters: The LinearDensity value in pounds_per_foot.
        :type pounds_per_foot: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(pounds_per_foot, LinearDensityUnits.PoundPerFoot)

    
    @staticmethod
    def from_grams_per_foot(grams_per_foot: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_foot.

        

        :param meters: The LinearDensity value in grams_per_foot.
        :type grams_per_foot: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_foot, LinearDensityUnits.GramPerFoot)

    
    @staticmethod
    def from_micrograms_per_millimeter(micrograms_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_millimeter.

        

        :param meters: The LinearDensity value in micrograms_per_millimeter.
        :type micrograms_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_millimeter, LinearDensityUnits.MicrogramPerMillimeter)

    
    @staticmethod
    def from_milligrams_per_millimeter(milligrams_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_millimeter.

        

        :param meters: The LinearDensity value in milligrams_per_millimeter.
        :type milligrams_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_millimeter, LinearDensityUnits.MilligramPerMillimeter)

    
    @staticmethod
    def from_kilograms_per_millimeter(kilograms_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_millimeter.

        

        :param meters: The LinearDensity value in kilograms_per_millimeter.
        :type kilograms_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_millimeter, LinearDensityUnits.KilogramPerMillimeter)

    
    @staticmethod
    def from_micrograms_per_centimeter(micrograms_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_centimeter.

        

        :param meters: The LinearDensity value in micrograms_per_centimeter.
        :type micrograms_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_centimeter, LinearDensityUnits.MicrogramPerCentimeter)

    
    @staticmethod
    def from_milligrams_per_centimeter(milligrams_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_centimeter.

        

        :param meters: The LinearDensity value in milligrams_per_centimeter.
        :type milligrams_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_centimeter, LinearDensityUnits.MilligramPerCentimeter)

    
    @staticmethod
    def from_kilograms_per_centimeter(kilograms_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_centimeter.

        

        :param meters: The LinearDensity value in kilograms_per_centimeter.
        :type kilograms_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_centimeter, LinearDensityUnits.KilogramPerCentimeter)

    
    @staticmethod
    def from_micrograms_per_meter(micrograms_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_meter.

        

        :param meters: The LinearDensity value in micrograms_per_meter.
        :type micrograms_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_meter, LinearDensityUnits.MicrogramPerMeter)

    
    @staticmethod
    def from_milligrams_per_meter(milligrams_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_meter.

        

        :param meters: The LinearDensity value in milligrams_per_meter.
        :type milligrams_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_meter, LinearDensityUnits.MilligramPerMeter)

    
    @staticmethod
    def from_kilograms_per_meter(kilograms_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_meter.

        

        :param meters: The LinearDensity value in kilograms_per_meter.
        :type kilograms_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_meter, LinearDensityUnits.KilogramPerMeter)

    
    @staticmethod
    def from_micrograms_per_foot(micrograms_per_foot: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_foot.

        

        :param meters: The LinearDensity value in micrograms_per_foot.
        :type micrograms_per_foot: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_foot, LinearDensityUnits.MicrogramPerFoot)

    
    @staticmethod
    def from_milligrams_per_foot(milligrams_per_foot: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_foot.

        

        :param meters: The LinearDensity value in milligrams_per_foot.
        :type milligrams_per_foot: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_foot, LinearDensityUnits.MilligramPerFoot)

    
    @staticmethod
    def from_kilograms_per_foot(kilograms_per_foot: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_foot.

        

        :param meters: The LinearDensity value in kilograms_per_foot.
        :type kilograms_per_foot: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_foot, LinearDensityUnits.KilogramPerFoot)

    
    @property
    def grams_per_millimeter(self) -> float:
        """
        
        """
        if self.__grams_per_millimeter != None:
            return self.__grams_per_millimeter
        self.__grams_per_millimeter = self.__convert_from_base(LinearDensityUnits.GramPerMillimeter)
        return self.__grams_per_millimeter

    
    @property
    def grams_per_centimeter(self) -> float:
        """
        
        """
        if self.__grams_per_centimeter != None:
            return self.__grams_per_centimeter
        self.__grams_per_centimeter = self.__convert_from_base(LinearDensityUnits.GramPerCentimeter)
        return self.__grams_per_centimeter

    
    @property
    def grams_per_meter(self) -> float:
        """
        
        """
        if self.__grams_per_meter != None:
            return self.__grams_per_meter
        self.__grams_per_meter = self.__convert_from_base(LinearDensityUnits.GramPerMeter)
        return self.__grams_per_meter

    
    @property
    def pounds_per_inch(self) -> float:
        """
        
        """
        if self.__pounds_per_inch != None:
            return self.__pounds_per_inch
        self.__pounds_per_inch = self.__convert_from_base(LinearDensityUnits.PoundPerInch)
        return self.__pounds_per_inch

    
    @property
    def pounds_per_foot(self) -> float:
        """
        
        """
        if self.__pounds_per_foot != None:
            return self.__pounds_per_foot
        self.__pounds_per_foot = self.__convert_from_base(LinearDensityUnits.PoundPerFoot)
        return self.__pounds_per_foot

    
    @property
    def grams_per_foot(self) -> float:
        """
        
        """
        if self.__grams_per_foot != None:
            return self.__grams_per_foot
        self.__grams_per_foot = self.__convert_from_base(LinearDensityUnits.GramPerFoot)
        return self.__grams_per_foot

    
    @property
    def micrograms_per_millimeter(self) -> float:
        """
        
        """
        if self.__micrograms_per_millimeter != None:
            return self.__micrograms_per_millimeter
        self.__micrograms_per_millimeter = self.__convert_from_base(LinearDensityUnits.MicrogramPerMillimeter)
        return self.__micrograms_per_millimeter

    
    @property
    def milligrams_per_millimeter(self) -> float:
        """
        
        """
        if self.__milligrams_per_millimeter != None:
            return self.__milligrams_per_millimeter
        self.__milligrams_per_millimeter = self.__convert_from_base(LinearDensityUnits.MilligramPerMillimeter)
        return self.__milligrams_per_millimeter

    
    @property
    def kilograms_per_millimeter(self) -> float:
        """
        
        """
        if self.__kilograms_per_millimeter != None:
            return self.__kilograms_per_millimeter
        self.__kilograms_per_millimeter = self.__convert_from_base(LinearDensityUnits.KilogramPerMillimeter)
        return self.__kilograms_per_millimeter

    
    @property
    def micrograms_per_centimeter(self) -> float:
        """
        
        """
        if self.__micrograms_per_centimeter != None:
            return self.__micrograms_per_centimeter
        self.__micrograms_per_centimeter = self.__convert_from_base(LinearDensityUnits.MicrogramPerCentimeter)
        return self.__micrograms_per_centimeter

    
    @property
    def milligrams_per_centimeter(self) -> float:
        """
        
        """
        if self.__milligrams_per_centimeter != None:
            return self.__milligrams_per_centimeter
        self.__milligrams_per_centimeter = self.__convert_from_base(LinearDensityUnits.MilligramPerCentimeter)
        return self.__milligrams_per_centimeter

    
    @property
    def kilograms_per_centimeter(self) -> float:
        """
        
        """
        if self.__kilograms_per_centimeter != None:
            return self.__kilograms_per_centimeter
        self.__kilograms_per_centimeter = self.__convert_from_base(LinearDensityUnits.KilogramPerCentimeter)
        return self.__kilograms_per_centimeter

    
    @property
    def micrograms_per_meter(self) -> float:
        """
        
        """
        if self.__micrograms_per_meter != None:
            return self.__micrograms_per_meter
        self.__micrograms_per_meter = self.__convert_from_base(LinearDensityUnits.MicrogramPerMeter)
        return self.__micrograms_per_meter

    
    @property
    def milligrams_per_meter(self) -> float:
        """
        
        """
        if self.__milligrams_per_meter != None:
            return self.__milligrams_per_meter
        self.__milligrams_per_meter = self.__convert_from_base(LinearDensityUnits.MilligramPerMeter)
        return self.__milligrams_per_meter

    
    @property
    def kilograms_per_meter(self) -> float:
        """
        
        """
        if self.__kilograms_per_meter != None:
            return self.__kilograms_per_meter
        self.__kilograms_per_meter = self.__convert_from_base(LinearDensityUnits.KilogramPerMeter)
        return self.__kilograms_per_meter

    
    @property
    def micrograms_per_foot(self) -> float:
        """
        
        """
        if self.__micrograms_per_foot != None:
            return self.__micrograms_per_foot
        self.__micrograms_per_foot = self.__convert_from_base(LinearDensityUnits.MicrogramPerFoot)
        return self.__micrograms_per_foot

    
    @property
    def milligrams_per_foot(self) -> float:
        """
        
        """
        if self.__milligrams_per_foot != None:
            return self.__milligrams_per_foot
        self.__milligrams_per_foot = self.__convert_from_base(LinearDensityUnits.MilligramPerFoot)
        return self.__milligrams_per_foot

    
    @property
    def kilograms_per_foot(self) -> float:
        """
        
        """
        if self.__kilograms_per_foot != None:
            return self.__kilograms_per_foot
        self.__kilograms_per_foot = self.__convert_from_base(LinearDensityUnits.KilogramPerFoot)
        return self.__kilograms_per_foot

    
    def to_string(self, unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter, fractional_digits: int = None) -> str:
        """
        Format the LinearDensity to a string.
        
        Note: the default format for LinearDensity is KilogramPerMeter.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the LinearDensity. Default is 'KilogramPerMeter'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == LinearDensityUnits.GramPerMillimeter:
            return f"""{super()._truncate_fraction_digits(self.grams_per_millimeter, fractional_digits)} g/mm"""
        
        if unit == LinearDensityUnits.GramPerCentimeter:
            return f"""{super()._truncate_fraction_digits(self.grams_per_centimeter, fractional_digits)} g/cm"""
        
        if unit == LinearDensityUnits.GramPerMeter:
            return f"""{super()._truncate_fraction_digits(self.grams_per_meter, fractional_digits)} g/m"""
        
        if unit == LinearDensityUnits.PoundPerInch:
            return f"""{super()._truncate_fraction_digits(self.pounds_per_inch, fractional_digits)} lb/in"""
        
        if unit == LinearDensityUnits.PoundPerFoot:
            return f"""{super()._truncate_fraction_digits(self.pounds_per_foot, fractional_digits)} lb/ft"""
        
        if unit == LinearDensityUnits.GramPerFoot:
            return f"""{super()._truncate_fraction_digits(self.grams_per_foot, fractional_digits)} g/ft"""
        
        if unit == LinearDensityUnits.MicrogramPerMillimeter:
            return f"""{super()._truncate_fraction_digits(self.micrograms_per_millimeter, fractional_digits)} μg/mm"""
        
        if unit == LinearDensityUnits.MilligramPerMillimeter:
            return f"""{super()._truncate_fraction_digits(self.milligrams_per_millimeter, fractional_digits)} mg/mm"""
        
        if unit == LinearDensityUnits.KilogramPerMillimeter:
            return f"""{super()._truncate_fraction_digits(self.kilograms_per_millimeter, fractional_digits)} kg/mm"""
        
        if unit == LinearDensityUnits.MicrogramPerCentimeter:
            return f"""{super()._truncate_fraction_digits(self.micrograms_per_centimeter, fractional_digits)} μg/cm"""
        
        if unit == LinearDensityUnits.MilligramPerCentimeter:
            return f"""{super()._truncate_fraction_digits(self.milligrams_per_centimeter, fractional_digits)} mg/cm"""
        
        if unit == LinearDensityUnits.KilogramPerCentimeter:
            return f"""{super()._truncate_fraction_digits(self.kilograms_per_centimeter, fractional_digits)} kg/cm"""
        
        if unit == LinearDensityUnits.MicrogramPerMeter:
            return f"""{super()._truncate_fraction_digits(self.micrograms_per_meter, fractional_digits)} μg/m"""
        
        if unit == LinearDensityUnits.MilligramPerMeter:
            return f"""{super()._truncate_fraction_digits(self.milligrams_per_meter, fractional_digits)} mg/m"""
        
        if unit == LinearDensityUnits.KilogramPerMeter:
            return f"""{super()._truncate_fraction_digits(self.kilograms_per_meter, fractional_digits)} kg/m"""
        
        if unit == LinearDensityUnits.MicrogramPerFoot:
            return f"""{super()._truncate_fraction_digits(self.micrograms_per_foot, fractional_digits)} μg/ft"""
        
        if unit == LinearDensityUnits.MilligramPerFoot:
            return f"""{super()._truncate_fraction_digits(self.milligrams_per_foot, fractional_digits)} mg/ft"""
        
        if unit == LinearDensityUnits.KilogramPerFoot:
            return f"""{super()._truncate_fraction_digits(self.kilograms_per_foot, fractional_digits)} kg/ft"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> str:
        """
        Get LinearDensity unit abbreviation.
        Note! the default abbreviation for LinearDensity is KilogramPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LinearDensityUnits.GramPerMillimeter:
            return """g/mm"""
        
        if unit_abbreviation == LinearDensityUnits.GramPerCentimeter:
            return """g/cm"""
        
        if unit_abbreviation == LinearDensityUnits.GramPerMeter:
            return """g/m"""
        
        if unit_abbreviation == LinearDensityUnits.PoundPerInch:
            return """lb/in"""
        
        if unit_abbreviation == LinearDensityUnits.PoundPerFoot:
            return """lb/ft"""
        
        if unit_abbreviation == LinearDensityUnits.GramPerFoot:
            return """g/ft"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerMillimeter:
            return """μg/mm"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerMillimeter:
            return """mg/mm"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerMillimeter:
            return """kg/mm"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerCentimeter:
            return """μg/cm"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerCentimeter:
            return """mg/cm"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerCentimeter:
            return """kg/cm"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerMeter:
            return """μg/m"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerMeter:
            return """mg/m"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerMeter:
            return """kg/m"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerFoot:
            return """μg/ft"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerFoot:
            return """mg/ft"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerFoot:
            return """kg/ft"""
        


from enum import Enum
import math

from ..abstract_unit import AbstractMeasure



class SpecificWeightUnits(Enum):
        """
            SpecificWeightUnits enumeration
        """
        
        NewtonPerCubicMillimeter = 'NewtonPerCubicMillimeter'
        """
            
        """
        
        NewtonPerCubicCentimeter = 'NewtonPerCubicCentimeter'
        """
            
        """
        
        NewtonPerCubicMeter = 'NewtonPerCubicMeter'
        """
            
        """
        
        KilogramForcePerCubicMillimeter = 'KilogramForcePerCubicMillimeter'
        """
            
        """
        
        KilogramForcePerCubicCentimeter = 'KilogramForcePerCubicCentimeter'
        """
            
        """
        
        KilogramForcePerCubicMeter = 'KilogramForcePerCubicMeter'
        """
            
        """
        
        PoundForcePerCubicInch = 'PoundForcePerCubicInch'
        """
            
        """
        
        PoundForcePerCubicFoot = 'PoundForcePerCubicFoot'
        """
            
        """
        
        TonneForcePerCubicMillimeter = 'TonneForcePerCubicMillimeter'
        """
            
        """
        
        TonneForcePerCubicCentimeter = 'TonneForcePerCubicCentimeter'
        """
            
        """
        
        TonneForcePerCubicMeter = 'TonneForcePerCubicMeter'
        """
            
        """
        
        KilonewtonPerCubicMillimeter = 'KilonewtonPerCubicMillimeter'
        """
            
        """
        
        KilonewtonPerCubicCentimeter = 'KilonewtonPerCubicCentimeter'
        """
            
        """
        
        KilonewtonPerCubicMeter = 'KilonewtonPerCubicMeter'
        """
            
        """
        
        MeganewtonPerCubicMeter = 'MeganewtonPerCubicMeter'
        """
            
        """
        
        KilopoundForcePerCubicInch = 'KilopoundForcePerCubicInch'
        """
            
        """
        
        KilopoundForcePerCubicFoot = 'KilopoundForcePerCubicFoot'
        """
            
        """
        

class SpecificWeightDto:
    """
    A DTO representation of a SpecificWeight

    Attributes:
        value (float): The value of the SpecificWeight.
        unit (SpecificWeightUnits): The specific unit that the SpecificWeight value is representing.
    """

    def __init__(self, value: float, unit: SpecificWeightUnits):
        """
        Create a new DTO representation of a SpecificWeight

        Parameters:
            value (float): The value of the SpecificWeight.
            unit (SpecificWeightUnits): The specific unit that the SpecificWeight value is representing.
        """
        self.value: float = value
        """
        The value of the SpecificWeight
        """
        self.unit: SpecificWeightUnits = unit
        """
        The specific unit that the SpecificWeight value is representing
        """

    def to_json(self):
        """
        Get a SpecificWeight DTO JSON object representing the current unit.

        :return: JSON object represents SpecificWeight DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "NewtonPerCubicMeter"}
        """
        return {"value": self.value, "unit": self.unit.value}

    @staticmethod
    def from_json(data):
        """
        Obtain a new instance of SpecificWeight DTO from a json representation.

        :param data: The SpecificWeight DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "NewtonPerCubicMeter"}
        :return: A new instance of SpecificWeightDto.
        :rtype: SpecificWeightDto
        """
        return SpecificWeightDto(value=data["value"], unit=SpecificWeightUnits(data["unit"]))


class SpecificWeight(AbstractMeasure):
    """
    The SpecificWeight, or more precisely, the volumetric weight density, of a substance is its weight per unit volume.

    Args:
        value (float): The value.
        from_unit (SpecificWeightUnits): The SpecificWeight unit to create from, The default unit is NewtonPerCubicMeter
    """
    def __init__(self, value: float, from_unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter):
        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
        # operations, but they are not a number, see #14 
        # if math.isnan(value):
        #     raise ValueError('Invalid unit: value is NaN')
        self._value = self.__convert_to_base(value, from_unit)
        
        self.__newtons_per_cubic_millimeter = None
        
        self.__newtons_per_cubic_centimeter = None
        
        self.__newtons_per_cubic_meter = None
        
        self.__kilograms_force_per_cubic_millimeter = None
        
        self.__kilograms_force_per_cubic_centimeter = None
        
        self.__kilograms_force_per_cubic_meter = None
        
        self.__pounds_force_per_cubic_inch = None
        
        self.__pounds_force_per_cubic_foot = None
        
        self.__tonnes_force_per_cubic_millimeter = None
        
        self.__tonnes_force_per_cubic_centimeter = None
        
        self.__tonnes_force_per_cubic_meter = None
        
        self.__kilonewtons_per_cubic_millimeter = None
        
        self.__kilonewtons_per_cubic_centimeter = None
        
        self.__kilonewtons_per_cubic_meter = None
        
        self.__meganewtons_per_cubic_meter = None
        
        self.__kilopounds_force_per_cubic_inch = None
        
        self.__kilopounds_force_per_cubic_foot = None
        

    def convert(self, unit: SpecificWeightUnits) -> float:
        return self.__convert_from_base(unit)

    def to_dto(self, hold_in_unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter) -> SpecificWeightDto:
        """
        Get a new instance of SpecificWeight DTO representing the current unit.

        :param hold_in_unit: The specific SpecificWeight unit to store the SpecificWeight value in the DTO representation.
        :type hold_in_unit: SpecificWeightUnits
        :return: A new instance of SpecificWeightDto.
        :rtype: SpecificWeightDto
        """
        return SpecificWeightDto(value=self.convert(hold_in_unit), unit=hold_in_unit)
    
    def to_dto_json(self, hold_in_unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter):
        """
        Get a SpecificWeight DTO JSON object representing the current unit.

        :param hold_in_unit: The specific SpecificWeight unit to store the SpecificWeight value in the DTO representation.
        :type hold_in_unit: SpecificWeightUnits
        :return: JSON object represents SpecificWeight DTO.
        :rtype: dict
        :example return: {"value": 100, "unit": "NewtonPerCubicMeter"}
        """
        return self.to_dto(hold_in_unit).to_json()

    @staticmethod
    def from_dto(specific_weight_dto: SpecificWeightDto):
        """
        Obtain a new instance of SpecificWeight from a DTO unit object.

        :param specific_weight_dto: The SpecificWeight DTO representation.
        :type specific_weight_dto: SpecificWeightDto
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(specific_weight_dto.value, specific_weight_dto.unit)

    @staticmethod
    def from_dto_json(data: dict):
        """
        Obtain a new instance of SpecificWeight from a DTO unit json representation.

        :param data: The SpecificWeight DTO in JSON representation.
        :type data: dict
        :example data: {"value": 100, "unit": "NewtonPerCubicMeter"}
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight.from_dto(SpecificWeightDto.from_json(data))

    def __convert_from_base(self, from_unit: SpecificWeightUnits) -> float:
        value = self._value
        
        if from_unit == SpecificWeightUnits.NewtonPerCubicMillimeter:
            return (value * 0.000000001)
        
        if from_unit == SpecificWeightUnits.NewtonPerCubicCentimeter:
            return (value * 0.000001)
        
        if from_unit == SpecificWeightUnits.NewtonPerCubicMeter:
            return (value)
        
        if from_unit == SpecificWeightUnits.KilogramForcePerCubicMillimeter:
            return (value / 9.80665e9)
        
        if from_unit == SpecificWeightUnits.KilogramForcePerCubicCentimeter:
            return (value / 9.80665e6)
        
        if from_unit == SpecificWeightUnits.KilogramForcePerCubicMeter:
            return (value / 9.80665)
        
        if from_unit == SpecificWeightUnits.PoundForcePerCubicInch:
            return (value / 2.714471375263134e5)
        
        if from_unit == SpecificWeightUnits.PoundForcePerCubicFoot:
            return (value / 1.570874638462462e2)
        
        if from_unit == SpecificWeightUnits.TonneForcePerCubicMillimeter:
            return (value / 9.80665e12)
        
        if from_unit == SpecificWeightUnits.TonneForcePerCubicCentimeter:
            return (value / 9.80665e9)
        
        if from_unit == SpecificWeightUnits.TonneForcePerCubicMeter:
            return (value / 9.80665e3)
        
        if from_unit == SpecificWeightUnits.KilonewtonPerCubicMillimeter:
            return ((value * 0.000000001) / 1000.0)
        
        if from_unit == SpecificWeightUnits.KilonewtonPerCubicCentimeter:
            return ((value * 0.000001) / 1000.0)
        
        if from_unit == SpecificWeightUnits.KilonewtonPerCubicMeter:
            return ((value) / 1000.0)
        
        if from_unit == SpecificWeightUnits.MeganewtonPerCubicMeter:
            return ((value) / 1000000.0)
        
        if from_unit == SpecificWeightUnits.KilopoundForcePerCubicInch:
            return ((value / 2.714471375263134e5) / 1000.0)
        
        if from_unit == SpecificWeightUnits.KilopoundForcePerCubicFoot:
            return ((value / 1.570874638462462e2) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: SpecificWeightUnits) -> float:
        
        if to_unit == SpecificWeightUnits.NewtonPerCubicMillimeter:
            return (value * 1000000000)
        
        if to_unit == SpecificWeightUnits.NewtonPerCubicCentimeter:
            return (value * 1000000)
        
        if to_unit == SpecificWeightUnits.NewtonPerCubicMeter:
            return (value)
        
        if to_unit == SpecificWeightUnits.KilogramForcePerCubicMillimeter:
            return (value * 9.80665e9)
        
        if to_unit == SpecificWeightUnits.KilogramForcePerCubicCentimeter:
            return (value * 9.80665e6)
        
        if to_unit == SpecificWeightUnits.KilogramForcePerCubicMeter:
            return (value * 9.80665)
        
        if to_unit == SpecificWeightUnits.PoundForcePerCubicInch:
            return (value * 2.714471375263134e5)
        
        if to_unit == SpecificWeightUnits.PoundForcePerCubicFoot:
            return (value * 1.570874638462462e2)
        
        if to_unit == SpecificWeightUnits.TonneForcePerCubicMillimeter:
            return (value * 9.80665e12)
        
        if to_unit == SpecificWeightUnits.TonneForcePerCubicCentimeter:
            return (value * 9.80665e9)
        
        if to_unit == SpecificWeightUnits.TonneForcePerCubicMeter:
            return (value * 9.80665e3)
        
        if to_unit == SpecificWeightUnits.KilonewtonPerCubicMillimeter:
            return ((value * 1000000000) * 1000.0)
        
        if to_unit == SpecificWeightUnits.KilonewtonPerCubicCentimeter:
            return ((value * 1000000) * 1000.0)
        
        if to_unit == SpecificWeightUnits.KilonewtonPerCubicMeter:
            return ((value) * 1000.0)
        
        if to_unit == SpecificWeightUnits.MeganewtonPerCubicMeter:
            return ((value) * 1000000.0)
        
        if to_unit == SpecificWeightUnits.KilopoundForcePerCubicInch:
            return ((value * 2.714471375263134e5) * 1000.0)
        
        if to_unit == SpecificWeightUnits.KilopoundForcePerCubicFoot:
            return ((value * 1.570874638462462e2) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self._value

    
    @staticmethod
    def from_newtons_per_cubic_millimeter(newtons_per_cubic_millimeter: float):
        """
        Create a new instance of SpecificWeight from a value in newtons_per_cubic_millimeter.

        

        :param meters: The SpecificWeight value in newtons_per_cubic_millimeter.
        :type newtons_per_cubic_millimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(newtons_per_cubic_millimeter, SpecificWeightUnits.NewtonPerCubicMillimeter)

    
    @staticmethod
    def from_newtons_per_cubic_centimeter(newtons_per_cubic_centimeter: float):
        """
        Create a new instance of SpecificWeight from a value in newtons_per_cubic_centimeter.

        

        :param meters: The SpecificWeight value in newtons_per_cubic_centimeter.
        :type newtons_per_cubic_centimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(newtons_per_cubic_centimeter, SpecificWeightUnits.NewtonPerCubicCentimeter)

    
    @staticmethod
    def from_newtons_per_cubic_meter(newtons_per_cubic_meter: float):
        """
        Create a new instance of SpecificWeight from a value in newtons_per_cubic_meter.

        

        :param meters: The SpecificWeight value in newtons_per_cubic_meter.
        :type newtons_per_cubic_meter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(newtons_per_cubic_meter, SpecificWeightUnits.NewtonPerCubicMeter)

    
    @staticmethod
    def from_kilograms_force_per_cubic_millimeter(kilograms_force_per_cubic_millimeter: float):
        """
        Create a new instance of SpecificWeight from a value in kilograms_force_per_cubic_millimeter.

        

        :param meters: The SpecificWeight value in kilograms_force_per_cubic_millimeter.
        :type kilograms_force_per_cubic_millimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilograms_force_per_cubic_millimeter, SpecificWeightUnits.KilogramForcePerCubicMillimeter)

    
    @staticmethod
    def from_kilograms_force_per_cubic_centimeter(kilograms_force_per_cubic_centimeter: float):
        """
        Create a new instance of SpecificWeight from a value in kilograms_force_per_cubic_centimeter.

        

        :param meters: The SpecificWeight value in kilograms_force_per_cubic_centimeter.
        :type kilograms_force_per_cubic_centimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilograms_force_per_cubic_centimeter, SpecificWeightUnits.KilogramForcePerCubicCentimeter)

    
    @staticmethod
    def from_kilograms_force_per_cubic_meter(kilograms_force_per_cubic_meter: float):
        """
        Create a new instance of SpecificWeight from a value in kilograms_force_per_cubic_meter.

        

        :param meters: The SpecificWeight value in kilograms_force_per_cubic_meter.
        :type kilograms_force_per_cubic_meter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilograms_force_per_cubic_meter, SpecificWeightUnits.KilogramForcePerCubicMeter)

    
    @staticmethod
    def from_pounds_force_per_cubic_inch(pounds_force_per_cubic_inch: float):
        """
        Create a new instance of SpecificWeight from a value in pounds_force_per_cubic_inch.

        

        :param meters: The SpecificWeight value in pounds_force_per_cubic_inch.
        :type pounds_force_per_cubic_inch: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(pounds_force_per_cubic_inch, SpecificWeightUnits.PoundForcePerCubicInch)

    
    @staticmethod
    def from_pounds_force_per_cubic_foot(pounds_force_per_cubic_foot: float):
        """
        Create a new instance of SpecificWeight from a value in pounds_force_per_cubic_foot.

        

        :param meters: The SpecificWeight value in pounds_force_per_cubic_foot.
        :type pounds_force_per_cubic_foot: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(pounds_force_per_cubic_foot, SpecificWeightUnits.PoundForcePerCubicFoot)

    
    @staticmethod
    def from_tonnes_force_per_cubic_millimeter(tonnes_force_per_cubic_millimeter: float):
        """
        Create a new instance of SpecificWeight from a value in tonnes_force_per_cubic_millimeter.

        

        :param meters: The SpecificWeight value in tonnes_force_per_cubic_millimeter.
        :type tonnes_force_per_cubic_millimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(tonnes_force_per_cubic_millimeter, SpecificWeightUnits.TonneForcePerCubicMillimeter)

    
    @staticmethod
    def from_tonnes_force_per_cubic_centimeter(tonnes_force_per_cubic_centimeter: float):
        """
        Create a new instance of SpecificWeight from a value in tonnes_force_per_cubic_centimeter.

        

        :param meters: The SpecificWeight value in tonnes_force_per_cubic_centimeter.
        :type tonnes_force_per_cubic_centimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(tonnes_force_per_cubic_centimeter, SpecificWeightUnits.TonneForcePerCubicCentimeter)

    
    @staticmethod
    def from_tonnes_force_per_cubic_meter(tonnes_force_per_cubic_meter: float):
        """
        Create a new instance of SpecificWeight from a value in tonnes_force_per_cubic_meter.

        

        :param meters: The SpecificWeight value in tonnes_force_per_cubic_meter.
        :type tonnes_force_per_cubic_meter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(tonnes_force_per_cubic_meter, SpecificWeightUnits.TonneForcePerCubicMeter)

    
    @staticmethod
    def from_kilonewtons_per_cubic_millimeter(kilonewtons_per_cubic_millimeter: float):
        """
        Create a new instance of SpecificWeight from a value in kilonewtons_per_cubic_millimeter.

        

        :param meters: The SpecificWeight value in kilonewtons_per_cubic_millimeter.
        :type kilonewtons_per_cubic_millimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilonewtons_per_cubic_millimeter, SpecificWeightUnits.KilonewtonPerCubicMillimeter)

    
    @staticmethod
    def from_kilonewtons_per_cubic_centimeter(kilonewtons_per_cubic_centimeter: float):
        """
        Create a new instance of SpecificWeight from a value in kilonewtons_per_cubic_centimeter.

        

        :param meters: The SpecificWeight value in kilonewtons_per_cubic_centimeter.
        :type kilonewtons_per_cubic_centimeter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilonewtons_per_cubic_centimeter, SpecificWeightUnits.KilonewtonPerCubicCentimeter)

    
    @staticmethod
    def from_kilonewtons_per_cubic_meter(kilonewtons_per_cubic_meter: float):
        """
        Create a new instance of SpecificWeight from a value in kilonewtons_per_cubic_meter.

        

        :param meters: The SpecificWeight value in kilonewtons_per_cubic_meter.
        :type kilonewtons_per_cubic_meter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilonewtons_per_cubic_meter, SpecificWeightUnits.KilonewtonPerCubicMeter)

    
    @staticmethod
    def from_meganewtons_per_cubic_meter(meganewtons_per_cubic_meter: float):
        """
        Create a new instance of SpecificWeight from a value in meganewtons_per_cubic_meter.

        

        :param meters: The SpecificWeight value in meganewtons_per_cubic_meter.
        :type meganewtons_per_cubic_meter: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(meganewtons_per_cubic_meter, SpecificWeightUnits.MeganewtonPerCubicMeter)

    
    @staticmethod
    def from_kilopounds_force_per_cubic_inch(kilopounds_force_per_cubic_inch: float):
        """
        Create a new instance of SpecificWeight from a value in kilopounds_force_per_cubic_inch.

        

        :param meters: The SpecificWeight value in kilopounds_force_per_cubic_inch.
        :type kilopounds_force_per_cubic_inch: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilopounds_force_per_cubic_inch, SpecificWeightUnits.KilopoundForcePerCubicInch)

    
    @staticmethod
    def from_kilopounds_force_per_cubic_foot(kilopounds_force_per_cubic_foot: float):
        """
        Create a new instance of SpecificWeight from a value in kilopounds_force_per_cubic_foot.

        

        :param meters: The SpecificWeight value in kilopounds_force_per_cubic_foot.
        :type kilopounds_force_per_cubic_foot: float
        :return: A new instance of SpecificWeight.
        :rtype: SpecificWeight
        """
        return SpecificWeight(kilopounds_force_per_cubic_foot, SpecificWeightUnits.KilopoundForcePerCubicFoot)

    
    @property
    def newtons_per_cubic_millimeter(self) -> float:
        """
        
        """
        if self.__newtons_per_cubic_millimeter != None:
            return self.__newtons_per_cubic_millimeter
        self.__newtons_per_cubic_millimeter = self.__convert_from_base(SpecificWeightUnits.NewtonPerCubicMillimeter)
        return self.__newtons_per_cubic_millimeter

    
    @property
    def newtons_per_cubic_centimeter(self) -> float:
        """
        
        """
        if self.__newtons_per_cubic_centimeter != None:
            return self.__newtons_per_cubic_centimeter
        self.__newtons_per_cubic_centimeter = self.__convert_from_base(SpecificWeightUnits.NewtonPerCubicCentimeter)
        return self.__newtons_per_cubic_centimeter

    
    @property
    def newtons_per_cubic_meter(self) -> float:
        """
        
        """
        if self.__newtons_per_cubic_meter != None:
            return self.__newtons_per_cubic_meter
        self.__newtons_per_cubic_meter = self.__convert_from_base(SpecificWeightUnits.NewtonPerCubicMeter)
        return self.__newtons_per_cubic_meter

    
    @property
    def kilograms_force_per_cubic_millimeter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_cubic_millimeter != None:
            return self.__kilograms_force_per_cubic_millimeter
        self.__kilograms_force_per_cubic_millimeter = self.__convert_from_base(SpecificWeightUnits.KilogramForcePerCubicMillimeter)
        return self.__kilograms_force_per_cubic_millimeter

    
    @property
    def kilograms_force_per_cubic_centimeter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_cubic_centimeter != None:
            return self.__kilograms_force_per_cubic_centimeter
        self.__kilograms_force_per_cubic_centimeter = self.__convert_from_base(SpecificWeightUnits.KilogramForcePerCubicCentimeter)
        return self.__kilograms_force_per_cubic_centimeter

    
    @property
    def kilograms_force_per_cubic_meter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_cubic_meter != None:
            return self.__kilograms_force_per_cubic_meter
        self.__kilograms_force_per_cubic_meter = self.__convert_from_base(SpecificWeightUnits.KilogramForcePerCubicMeter)
        return self.__kilograms_force_per_cubic_meter

    
    @property
    def pounds_force_per_cubic_inch(self) -> float:
        """
        
        """
        if self.__pounds_force_per_cubic_inch != None:
            return self.__pounds_force_per_cubic_inch
        self.__pounds_force_per_cubic_inch = self.__convert_from_base(SpecificWeightUnits.PoundForcePerCubicInch)
        return self.__pounds_force_per_cubic_inch

    
    @property
    def pounds_force_per_cubic_foot(self) -> float:
        """
        
        """
        if self.__pounds_force_per_cubic_foot != None:
            return self.__pounds_force_per_cubic_foot
        self.__pounds_force_per_cubic_foot = self.__convert_from_base(SpecificWeightUnits.PoundForcePerCubicFoot)
        return self.__pounds_force_per_cubic_foot

    
    @property
    def tonnes_force_per_cubic_millimeter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_cubic_millimeter != None:
            return self.__tonnes_force_per_cubic_millimeter
        self.__tonnes_force_per_cubic_millimeter = self.__convert_from_base(SpecificWeightUnits.TonneForcePerCubicMillimeter)
        return self.__tonnes_force_per_cubic_millimeter

    
    @property
    def tonnes_force_per_cubic_centimeter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_cubic_centimeter != None:
            return self.__tonnes_force_per_cubic_centimeter
        self.__tonnes_force_per_cubic_centimeter = self.__convert_from_base(SpecificWeightUnits.TonneForcePerCubicCentimeter)
        return self.__tonnes_force_per_cubic_centimeter

    
    @property
    def tonnes_force_per_cubic_meter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_cubic_meter != None:
            return self.__tonnes_force_per_cubic_meter
        self.__tonnes_force_per_cubic_meter = self.__convert_from_base(SpecificWeightUnits.TonneForcePerCubicMeter)
        return self.__tonnes_force_per_cubic_meter

    
    @property
    def kilonewtons_per_cubic_millimeter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_cubic_millimeter != None:
            return self.__kilonewtons_per_cubic_millimeter
        self.__kilonewtons_per_cubic_millimeter = self.__convert_from_base(SpecificWeightUnits.KilonewtonPerCubicMillimeter)
        return self.__kilonewtons_per_cubic_millimeter

    
    @property
    def kilonewtons_per_cubic_centimeter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_cubic_centimeter != None:
            return self.__kilonewtons_per_cubic_centimeter
        self.__kilonewtons_per_cubic_centimeter = self.__convert_from_base(SpecificWeightUnits.KilonewtonPerCubicCentimeter)
        return self.__kilonewtons_per_cubic_centimeter

    
    @property
    def kilonewtons_per_cubic_meter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_cubic_meter != None:
            return self.__kilonewtons_per_cubic_meter
        self.__kilonewtons_per_cubic_meter = self.__convert_from_base(SpecificWeightUnits.KilonewtonPerCubicMeter)
        return self.__kilonewtons_per_cubic_meter

    
    @property
    def meganewtons_per_cubic_meter(self) -> float:
        """
        
        """
        if self.__meganewtons_per_cubic_meter != None:
            return self.__meganewtons_per_cubic_meter
        self.__meganewtons_per_cubic_meter = self.__convert_from_base(SpecificWeightUnits.MeganewtonPerCubicMeter)
        return self.__meganewtons_per_cubic_meter

    
    @property
    def kilopounds_force_per_cubic_inch(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_cubic_inch != None:
            return self.__kilopounds_force_per_cubic_inch
        self.__kilopounds_force_per_cubic_inch = self.__convert_from_base(SpecificWeightUnits.KilopoundForcePerCubicInch)
        return self.__kilopounds_force_per_cubic_inch

    
    @property
    def kilopounds_force_per_cubic_foot(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_cubic_foot != None:
            return self.__kilopounds_force_per_cubic_foot
        self.__kilopounds_force_per_cubic_foot = self.__convert_from_base(SpecificWeightUnits.KilopoundForcePerCubicFoot)
        return self.__kilopounds_force_per_cubic_foot

    
    def to_string(self, unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter, fractional_digits: int = None) -> str:
        """
        Format the SpecificWeight to a string.
        
        Note: the default format for SpecificWeight is NewtonPerCubicMeter.
        To specify the unit format, set the 'unit' parameter.
        
        Args:
            unit (str): The unit to format the SpecificWeight. Default is 'NewtonPerCubicMeter'.
            fractional_digits (int, optional): The number of fractional digits to keep.

        Returns:
            str: The string format of the Angle.
        """
        
        if unit == SpecificWeightUnits.NewtonPerCubicMillimeter:
            return f"""{super()._truncate_fraction_digits(self.newtons_per_cubic_millimeter, fractional_digits)} N/mm³"""
        
        if unit == SpecificWeightUnits.NewtonPerCubicCentimeter:
            return f"""{super()._truncate_fraction_digits(self.newtons_per_cubic_centimeter, fractional_digits)} N/cm³"""
        
        if unit == SpecificWeightUnits.NewtonPerCubicMeter:
            return f"""{super()._truncate_fraction_digits(self.newtons_per_cubic_meter, fractional_digits)} N/m³"""
        
        if unit == SpecificWeightUnits.KilogramForcePerCubicMillimeter:
            return f"""{super()._truncate_fraction_digits(self.kilograms_force_per_cubic_millimeter, fractional_digits)} kgf/mm³"""
        
        if unit == SpecificWeightUnits.KilogramForcePerCubicCentimeter:
            return f"""{super()._truncate_fraction_digits(self.kilograms_force_per_cubic_centimeter, fractional_digits)} kgf/cm³"""
        
        if unit == SpecificWeightUnits.KilogramForcePerCubicMeter:
            return f"""{super()._truncate_fraction_digits(self.kilograms_force_per_cubic_meter, fractional_digits)} kgf/m³"""
        
        if unit == SpecificWeightUnits.PoundForcePerCubicInch:
            return f"""{super()._truncate_fraction_digits(self.pounds_force_per_cubic_inch, fractional_digits)} lbf/in³"""
        
        if unit == SpecificWeightUnits.PoundForcePerCubicFoot:
            return f"""{super()._truncate_fraction_digits(self.pounds_force_per_cubic_foot, fractional_digits)} lbf/ft³"""
        
        if unit == SpecificWeightUnits.TonneForcePerCubicMillimeter:
            return f"""{super()._truncate_fraction_digits(self.tonnes_force_per_cubic_millimeter, fractional_digits)} tf/mm³"""
        
        if unit == SpecificWeightUnits.TonneForcePerCubicCentimeter:
            return f"""{super()._truncate_fraction_digits(self.tonnes_force_per_cubic_centimeter, fractional_digits)} tf/cm³"""
        
        if unit == SpecificWeightUnits.TonneForcePerCubicMeter:
            return f"""{super()._truncate_fraction_digits(self.tonnes_force_per_cubic_meter, fractional_digits)} tf/m³"""
        
        if unit == SpecificWeightUnits.KilonewtonPerCubicMillimeter:
            return f"""{super()._truncate_fraction_digits(self.kilonewtons_per_cubic_millimeter, fractional_digits)} kN/mm³"""
        
        if unit == SpecificWeightUnits.KilonewtonPerCubicCentimeter:
            return f"""{super()._truncate_fraction_digits(self.kilonewtons_per_cubic_centimeter, fractional_digits)} kN/cm³"""
        
        if unit == SpecificWeightUnits.KilonewtonPerCubicMeter:
            return f"""{super()._truncate_fraction_digits(self.kilonewtons_per_cubic_meter, fractional_digits)} kN/m³"""
        
        if unit == SpecificWeightUnits.MeganewtonPerCubicMeter:
            return f"""{super()._truncate_fraction_digits(self.meganewtons_per_cubic_meter, fractional_digits)} MN/m³"""
        
        if unit == SpecificWeightUnits.KilopoundForcePerCubicInch:
            return f"""{super()._truncate_fraction_digits(self.kilopounds_force_per_cubic_inch, fractional_digits)} klbf/in³"""
        
        if unit == SpecificWeightUnits.KilopoundForcePerCubicFoot:
            return f"""{super()._truncate_fraction_digits(self.kilopounds_force_per_cubic_foot, fractional_digits)} klbf/ft³"""
        
        return f'{self._value}'


    def get_unit_abbreviation(self, unit_abbreviation: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter) -> str:
        """
        Get SpecificWeight unit abbreviation.
        Note! the default abbreviation for SpecificWeight is NewtonPerCubicMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == SpecificWeightUnits.NewtonPerCubicMillimeter:
            return """N/mm³"""
        
        if unit_abbreviation == SpecificWeightUnits.NewtonPerCubicCentimeter:
            return """N/cm³"""
        
        if unit_abbreviation == SpecificWeightUnits.NewtonPerCubicMeter:
            return """N/m³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilogramForcePerCubicMillimeter:
            return """kgf/mm³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilogramForcePerCubicCentimeter:
            return """kgf/cm³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilogramForcePerCubicMeter:
            return """kgf/m³"""
        
        if unit_abbreviation == SpecificWeightUnits.PoundForcePerCubicInch:
            return """lbf/in³"""
        
        if unit_abbreviation == SpecificWeightUnits.PoundForcePerCubicFoot:
            return """lbf/ft³"""
        
        if unit_abbreviation == SpecificWeightUnits.TonneForcePerCubicMillimeter:
            return """tf/mm³"""
        
        if unit_abbreviation == SpecificWeightUnits.TonneForcePerCubicCentimeter:
            return """tf/cm³"""
        
        if unit_abbreviation == SpecificWeightUnits.TonneForcePerCubicMeter:
            return """tf/m³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilonewtonPerCubicMillimeter:
            return """kN/mm³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilonewtonPerCubicCentimeter:
            return """kN/cm³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilonewtonPerCubicMeter:
            return """kN/m³"""
        
        if unit_abbreviation == SpecificWeightUnits.MeganewtonPerCubicMeter:
            return """MN/m³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilopoundForcePerCubicInch:
            return """klbf/in³"""
        
        if unit_abbreviation == SpecificWeightUnits.KilopoundForcePerCubicFoot:
            return """klbf/ft³"""
        